@@ -7,6 +7,7 @@
 import subprocess
 import sys
 import os
+import time
 
 
 def install(package: str, check=True):
@@ -23,9 +24,11 @@ def pip_upgrade():
 
 
 def required():
-    require = ["requests", "opencv-python", "progress"]
+    install("python-time")
+    require = ["requests", "opencv-python", "progress", "dearpygui"]
     print("Установка необходимых библиотек...")
     for i in range(len(require)):
         install(require[i], check=False)
         print(f"Status: {i + 1} of {len(require)}")
-    print("Установка завершена.")
\ No newline at end of file
+    print("Установка завершена.")
+    time.sleep(1)
